==> webkit2gtk_2.47.4.orig.tar.xz: webkitgtk-2.47.4/Source/WTF/wtf/ContinuousApproximateTime.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include <wtf/ContinuousApproximateTime.h>

#include <wtf/MonotonicTime.h>
#include <wtf/PrintStream.h>
#include <wtf/WallTime.h>

namespace WTF {

WallTime ContinuousApproximateTime::approximateWallTime() const
{
    if (isInfinity())
        return WallTime::fromRawSeconds(m_value);
    return *this - now() + WallTime::now();
}

MonotonicTime ContinuousApproximateTime::approximateMonotonicTime() const
{
    if (isInfinity())
        return MonotonicTime::fromRawSeconds(m_value);
    return *this - now() + MonotonicTime::now();
}

void ContinuousApproximateTime::dump(PrintStream& out) const
{
    out.print("ContinuousApproximate(", m_value, " sec)");
}

} // namespace WTF

==> webkit2gtk_2.48.6.orig.tar.xz: webkitgtk-2.48.6/Source/WTF/wtf/ContinuousApproximateTime.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include <wtf/ContinuousApproximateTime.h>

#include <wtf/MonotonicTime.h>
#include <wtf/PrintStream.h>
#include <wtf/WallTime.h>

namespace WTF {

ContinuousApproximateTime ContinuousApproximateTime::fromWallTime(WallTime wallTime)
{
    return now() + (wallTime - WallTime::now());
}

WallTime ContinuousApproximateTime::approximateWallTime() const
{
    if (isInfinity())
        return WallTime::fromRawSeconds(m_value);
    return *this - now() + WallTime::now();
}

MonotonicTime ContinuousApproximateTime::approximateMonotonicTime() const
{
    if (isInfinity())
        return MonotonicTime::fromRawSeconds(m_value);
    return *this - now() + MonotonicTime::now();
}

void ContinuousApproximateTime::dump(PrintStream& out) const
{
    out.print("ContinuousApproximate(", m_value, " sec)");
}

} // namespace WTF
